Color

Enum Color 

pub enum Color {
    Simple(SimpleColor),
    Indexed(IndexedColor),
    RGB(RGBColor),
}
An enum representing all supported color types.

Variants



Simple(SimpleColor)

A simple color (16 colors).



Indexed(IndexedColor)

An 8-bit color (256 colors).



RGB(RGBColor)

An RGB color (24-bit/true color).

Implementations

Source

impl Color

pub const BLACK: BasicColor = BasicColor::Black

Constant for the basic color black.

pub const RED: BasicColor = BasicColor::Red

Constant for the basic color red.

pub const GREEN: BasicColor = BasicColor::Green

Constant for the basic color green.

pub const YELLOW: BasicColor = BasicColor::Yellow

Constant for the basic color yellow.

pub const BLUE: BasicColor = BasicColor::Blue

Constant for the basic color blue.

pub const MAGENTA: BasicColor = BasicColor::Magenta

Constant for the basic color magenta.

pub const CYAN: BasicColor = BasicColor::Cyan

Constant for the basic color cyan.

pub const WHITE: BasicColor = BasicColor::White

Constant for the basic color white.

pub const fn indexed(value: u8) -> IndexedColor

Create an 8-bit color from the given value.

pub const fn rgb(r: u8, g: u8, b: u8) -> RGBColor

Create an RGB color from the given red, green, and blue components.

pub const fn none() -> Option<Color>

Helper method to return a None value.

Use it to clear the color for some target with Style::set_color() or Styled<C>::set_color().

Source

impl Color

pub fn for_fg(self) -> TargetedColor

Associate this color with the foreground plane.

pub fn for_bg(self) -> TargetedColor

Associate this color with the background plane.

pub fn for_underline(self) -> TargetedColor

Associate this color with the underline effect.

pub fn for_target(self, target: ColorTarget) -> TargetedColor

Associate this color with the specified color target.

Source

impl Color

pub fn bold(self) -> Style

Sets the bold effect.

pub fn faint(self) -> Style

Sets the faint effect.

pub fn italic(self) -> Style

Sets the italic effect.

pub fn underline(self) -> Style

pub fn solid_underline(self) -> Style

Sets the solid underline effect.

pub fn curly_underline(self) -> Style

Sets the curly underline effect.

pub fn dotted_underline(self) -> Style

Sets the dotted underline effect.

pub fn dashed_underline(self) -> Style

Sets the dashed underline effect.

Sets the blink effect.

pub fn reverse(self) -> Style

Sets the reverse effect.

pub fn conceal(self) -> Style

Sets the conceal effect.

pub fn strikethrough(self) -> Style

Sets the strikethrough effect.

pub fn double_underline(self) -> Style

Sets the double underline effect.

pub fn overline(self) -> Style

Sets the overline effect.

pub fn effect(self, effect: impl Into<Effect>) -> Style

Sets the given effect.

pub fn underline_effect(self, underline_effect: UnderlineEffect) -> Style

Sets the underline effect.

pub fn fg(self, color: impl Into<Color>) -> Style

Sets the foreground color.

pub fn bg(self, color: impl Into<Color>) -> Style

Sets the background color.

pub fn underline_color(self, color: impl Into<Color>) -> Style

Sets the underline color.

pub fn color(self, targeted_color: impl Into<TargetedColor>) -> Style

Sets the given color in a target.

pub fn add(self, element: impl StylingElement<Style>) -> Style

Adds the given element to the style.

pub fn applied_to<C: Display>(self, content: C) -> Styled<C>

Applies the styling to the given content, returning a Styled<C> instance.

Source

impl Color

pub fn to_style(self) -> Style

Converts the type into a Style.

Source

impl Color

pub fn to_color(self) -> Color

Convert this type into a Color.

Source

impl Color

pub fn to_targeted_color(self) -> TargetedColor

Converts the type into a TargetedColor