IndexedColor

Struct IndexedColor 

pub struct IndexedColor(pub u8);
An 8-bit color type representing colors in the 256-color ANSI palette.

These colors are also available from the method Color::indexed():

use fluent_ansi::{prelude::*, color::IndexedColor};

assert_eq!(Color::indexed(127), IndexedColor(127));

See Wikipedia’s article on 8-bit colors ANSI escape codes.

Tuple Fields

0: u8

Implementations

Source

impl IndexedColor

pub const fn new(index: u8) -> Self

Creates a new 8-bit color with the given color index (0-255).

pub const fn get_index(self) -> u8

Returns the color index of this 8-bit color.

Source

impl IndexedColor

pub fn for_fg(self) -> TargetedColor

Associate this color with the foreground plane.

pub fn for_bg(self) -> TargetedColor

Associate this color with the background plane.

pub fn for_underline(self) -> TargetedColor

Associate this color with the underline effect.

pub fn for_target(self, target: ColorTarget) -> TargetedColor

Associate this color with the specified color target.

Source

impl IndexedColor

pub fn bold(self) -> Style

Sets the bold effect.

pub fn faint(self) -> Style

Sets the faint effect.

pub fn italic(self) -> Style

Sets the italic effect.

pub fn underline(self) -> Style

pub fn solid_underline(self) -> Style

Sets the solid underline effect.

pub fn curly_underline(self) -> Style

Sets the curly underline effect.

pub fn dotted_underline(self) -> Style

Sets the dotted underline effect.

pub fn dashed_underline(self) -> Style

Sets the dashed underline effect.

Sets the blink effect.

pub fn reverse(self) -> Style

Sets the reverse effect.

pub fn conceal(self) -> Style

Sets the conceal effect.

pub fn strikethrough(self) -> Style

Sets the strikethrough effect.

pub fn double_underline(self) -> Style

Sets the double underline effect.

pub fn overline(self) -> Style

Sets the overline effect.

pub fn effect(self, effect: impl Into<Effect>) -> Style

Sets the given effect.

pub fn underline_effect(self, underline_effect: UnderlineEffect) -> Style

Sets the underline effect.

pub fn fg(self, color: impl Into<Color>) -> Style

Sets the foreground color.

pub fn bg(self, color: impl Into<Color>) -> Style

Sets the background color.

pub fn underline_color(self, color: impl Into<Color>) -> Style

Sets the underline color.

pub fn color(self, targeted_color: impl Into<TargetedColor>) -> Style

Sets the given color in a target.

pub fn add(self, element: impl StylingElement<Style>) -> Style

Adds the given element to the style.

pub fn applied_to<C: Display>(self, content: C) -> Styled<C>

Applies the styling to the given content, returning a Styled<C> instance.

Source

impl IndexedColor

pub fn to_style(self) -> Style

Converts the type into a Style.

Source

impl IndexedColor

pub fn to_color(self) -> Color

Convert this type into a Color.

Source

impl IndexedColor

pub fn to_targeted_color(self) -> TargetedColor

Converts the type into a TargetedColor