SimpleColor

Struct SimpleColor 

pub struct SimpleColor { /* private fields */ }
A simple color type representing the 16 basic terminal colors (8 basic colors + bright variants).

These colors are also available as associated BasicColor constants in the Color enum, which can be turned into a SimpleColor value:

use fluent_ansi::{prelude::*, color::{BasicColor, SimpleColor}};

assert_eq!(Color::RED.to_simple_color(), SimpleColor::new(BasicColor::Red));
assert_eq!(Color::RED.bright(), SimpleColor::new_bright(BasicColor::Red));

See Wikipedia’s article on 3-bit and 4-bit colors ANSI escape codes.

Implementations

Source

impl SimpleColor

pub const fn new(basic_color: BasicColor) -> Self

Creates a new simple, non-bright color.

pub const fn new_bright(basic_color: BasicColor) -> Self

Creates a new bright simple color.

pub const fn bright(self) -> Self

Returns a bright variant of this simple color.

pub const fn get_basic_color(self) -> BasicColor

Returns the basic color of this simple color.

pub const fn is_bright(self) -> bool

Returns whether this simple color is bright.

Source

impl SimpleColor

pub fn for_fg(self) -> TargetedColor

Associate this color with the foreground plane.

pub fn for_bg(self) -> TargetedColor

Associate this color with the background plane.

pub fn for_underline(self) -> TargetedColor

Associate this color with the underline effect.

pub fn for_target(self, target: ColorTarget) -> TargetedColor

Associate this color with the specified color target.

Source

impl SimpleColor

pub fn bold(self) -> Style

Sets the bold effect.

pub fn faint(self) -> Style

Sets the faint effect.

pub fn italic(self) -> Style

Sets the italic effect.

pub fn underline(self) -> Style

pub fn solid_underline(self) -> Style

Sets the solid underline effect.

pub fn curly_underline(self) -> Style

Sets the curly underline effect.

pub fn dotted_underline(self) -> Style

Sets the dotted underline effect.

pub fn dashed_underline(self) -> Style

Sets the dashed underline effect.

Sets the blink effect.

pub fn reverse(self) -> Style

Sets the reverse effect.

pub fn conceal(self) -> Style

Sets the conceal effect.

pub fn strikethrough(self) -> Style

Sets the strikethrough effect.

pub fn double_underline(self) -> Style

Sets the double underline effect.

pub fn overline(self) -> Style

Sets the overline effect.

pub fn effect(self, effect: impl Into<Effect>) -> Style

Sets the given effect.

pub fn underline_effect(self, underline_effect: UnderlineEffect) -> Style

Sets the underline effect.

pub fn fg(self, color: impl Into<Color>) -> Style

Sets the foreground color.

pub fn bg(self, color: impl Into<Color>) -> Style

Sets the background color.

pub fn underline_color(self, color: impl Into<Color>) -> Style

Sets the underline color.

pub fn color(self, targeted_color: impl Into<TargetedColor>) -> Style

Sets the given color in a target.

pub fn add(self, element: impl StylingElement<Style>) -> Style

Adds the given element to the style.

pub fn applied_to<C: Display>(self, content: C) -> Styled<C>

Applies the styling to the given content, returning a Styled<C> instance.

Source

impl SimpleColor

pub fn to_style(self) -> Style

Converts the type into a Style.

Source

impl SimpleColor

pub fn to_color(self) -> Color

Convert this type into a Color.

Source

impl SimpleColor

pub fn to_targeted_color(self) -> TargetedColor

Converts the type into a TargetedColor