Styled

Struct Styled 

pub struct Styled<C: Display> { /* private fields */ }
A value that associates some content with a specific style.

Implementations

Source

impl<C: Display> Styled<C>

pub const fn new(content: C) -> Self

Creates a new Styled<C> value with the given content and empty style.

pub const fn get_content(&self) -> &C

Gets a reference to the enclosed content.

pub const fn with_content<C2: Display>(&self, content: C2) -> Styled<C2>

Returns a new Styled<C2> value with the same style and the given content.

pub fn into_content(self) -> C

Consumes the Styled<C> value and returns the enclosed content.

pub const fn get_style(&self) -> Style

Gets the current style.

pub fn with_style(self, style: Style) -> Styled<C>

Returns a new Styled<C> value with the same content and the given style.

pub fn bold(self) -> Styled<C>

Sets the bold effect.

pub fn faint(self) -> Styled<C>

Sets the faint effect.

pub fn italic(self) -> Styled<C>

Sets the italic effect.

pub fn underline(self) -> Styled<C>

pub fn solid_underline(self) -> Styled<C>

Sets the solid underline effect.

pub fn curly_underline(self) -> Styled<C>

Sets the curly underline effect.

pub fn dotted_underline(self) -> Styled<C>

Sets the dotted underline effect.

pub fn dashed_underline(self) -> Styled<C>

Sets the dashed underline effect.

Sets the blink effect.

pub fn reverse(self) -> Styled<C>

Sets the reverse effect.

pub fn conceal(self) -> Styled<C>

Sets the conceal effect.

pub fn strikethrough(self) -> Styled<C>

Sets the strikethrough effect.

pub fn double_underline(self) -> Styled<C>

Sets the double underline effect.

pub fn overline(self) -> Styled<C>

Sets the overline effect.

pub fn effect(self, effect: impl Into<Effect>) -> Styled<C>

Sets the given effect.

pub fn underline_effect(self, underline_effect: UnderlineEffect) -> Styled<C>

Sets the underline effect.

pub fn fg(self, color: impl Into<Color>) -> Styled<C>

Sets the foreground color.

pub fn bg(self, color: impl Into<Color>) -> Styled<C>

Sets the background color.

pub fn underline_color(self, color: impl Into<Color>) -> Styled<C>

Sets the underline color.

pub fn color(self, targeted_color: impl Into<TargetedColor>) -> Styled<C>

Sets the given color in a target.

pub fn add(self, element: impl StylingElement<Styled<C>>) -> Styled<C>

Adds the given element to the style.

pub fn set_effect(self, effect: impl Into<Effect>, value: bool) -> Self

Sets the given effect to the specified value.

pub fn get_effect(&self, effect: impl Into<Effect>) -> bool

Gets whether the given effect is set.

pub fn get_effects(&self) -> GetEffects

Returns an iterator over the effects that are currently set.

pub fn set_underline_effect( self, underline_effect: Option<UnderlineEffect>, ) -> Self

Sets the underline effect.

pub fn get_underline_effect(&self) -> Option<UnderlineEffect>

Gets the underline effect.

pub fn set_color( self, target: ColorTarget, color: Option<impl Into<Color>>, ) -> Self

Sets the color for the given color target.

To clear the color for some color target, the color type must be specified in the None value. To help with that, the Color::none() method can be used:

styled.set_color(ColorTarget::Foreground, None::<Color>);
// or
styled.set_color(ColorTarget::Foreground, Color::none());
pub fn get_color(&self, target: ColorTarget) -> Option<Color>

Gets the color for the given color target.

pub fn set<A: StylingAttribute<Self>>(self, attr: A, value: A::Value) -> Self

Sets the given attribute to the specified value.

pub fn get<A: StylingAttribute<Self>>(&self, attr: A) -> A::Value

Gets the value of the given attribute.

pub fn remove<A: StylingAttribute<Self>>(self, attr: A) -> Self

Clears the given attribute.