pub struct TargetedColor { /* private fields */ }Expand description
A color in a specific color target.
Implementations
Sourceimpl TargetedColor
impl TargetedColor
Sourcepub fn new(color: impl Into<Color>, target: ColorTarget) -> Self
pub fn new(color: impl Into<Color>, target: ColorTarget) -> Self
Creates a new color for a specific color target.
Sourcepub fn new_for_fg(color: impl Into<Color>) -> Self
pub fn new_for_fg(color: impl Into<Color>) -> Self
Creates a new color for the foreground plane.
Sourcepub fn new_for_bg(color: impl Into<Color>) -> Self
pub fn new_for_bg(color: impl Into<Color>) -> Self
Creates a new color for the background plane.
Sourcepub fn new_for_underline(color: impl Into<Color>) -> Self
pub fn new_for_underline(color: impl Into<Color>) -> Self
Creates a new color for the underline effects.
Sourcepub const fn get_target(self) -> ColorTarget
pub const fn get_target(self) -> ColorTarget
Gets the color target.
Sourceimpl TargetedColor
impl TargetedColor
Sourcepub fn underline(self) -> Style
pub fn underline(self) -> Style
An alias for Self::solid_underline().
Sourcepub fn solid_underline(self) -> Style
pub fn solid_underline(self) -> Style
Sets the solid underline effect.
Sourcepub fn curly_underline(self) -> Style
pub fn curly_underline(self) -> Style
Sets the curly underline effect.
Sourcepub fn dotted_underline(self) -> Style
pub fn dotted_underline(self) -> Style
Sets the dotted underline effect.
Sourcepub fn dashed_underline(self) -> Style
pub fn dashed_underline(self) -> Style
Sets the dashed underline effect.
Sourcepub fn strikethrough(self) -> Style
pub fn strikethrough(self) -> Style
Sets the strikethrough effect.
Sourcepub fn double_underline(self) -> Style
pub fn double_underline(self) -> Style
Sets the double underline effect.
Sourcepub fn underline_effect(self, underline_effect: UnderlineEffect) -> Style
pub fn underline_effect(self, underline_effect: UnderlineEffect) -> Style
Sets the underline effect.
Sourcepub fn underline_color(self, color: impl Into<Color>) -> Style
pub fn underline_color(self, color: impl Into<Color>) -> Style
Sets the underline color.
Sourcepub fn color(self, targeted_color: impl Into<TargetedColor>) -> Style
pub fn color(self, targeted_color: impl Into<TargetedColor>) -> Style
Sets the given color in a target.
Sourcepub fn add(self, element: impl StylingElement<Style>) -> Style
pub fn add(self, element: impl StylingElement<Style>) -> Style
Adds the given element to the style.
Sourcepub fn applied_to<C: Display>(self, content: C) -> Styled<C>
pub fn applied_to<C: Display>(self, content: C) -> Styled<C>
Applies the styling to the given content, returning a Styled<C> instance.