StylingElement

Trait StylingElement 

pub trait StylingElement<S> {
    // Required method
    fn add_to(self, style_set: S) -> S;
}
An element that can be composed with any styling type.

This trait is used to define elements that can be added to a Style. Such elements include effects (Effect) and colors (like TargetedColor).

Required Methods

fn add_to(self, style_set: S) -> S

Adds this element to the given parameter, returning it updated.

Implementors