Style

Struct Style 

pub struct Style { /* private fields */ }
A structure representing text styling with effects and colors.

Implementations

Source

impl Style

pub const fn new() -> Self

Creates a new, empty Style value.

pub fn set_effect(self, effect: impl Into<Effect>, value: bool) -> Self

Sets the given effect to the specified value.

pub fn get_effect(&self, effect: impl Into<Effect>) -> bool

Gets whether the given effect is set.

pub fn get_effects(&self) -> GetEffects

Returns an iterator over the effects that are currently set.

pub fn set_underline_effect( self, underline_effect: Option<UnderlineEffect>, ) -> Self

Sets the underline effect.

pub fn get_underline_effect(&self) -> Option<UnderlineEffect>

Gets the underline effect.

pub fn set_color( self, target: ColorTarget, color: Option<impl Into<Color>>, ) -> Self

Sets the color for the given color target.

To clear the color for some color target, the color type must be specified in the None value. To help with that, the Color::none() method can be used:

style.set_color(ColorTarget::Foreground, None::<Color>);
// or
style.set_color(ColorTarget::Foreground, Color::none());
pub fn get_color(&self, target: ColorTarget) -> Option<Color>

Gets the color for the given color target.

pub fn set<A: StylingAttribute<Self>>(self, attr: A, value: A::Value) -> Self

Sets the given attribute to the specified value.

pub fn get<A: StylingAttribute<Self>>(&self, attr: A) -> A::Value

Gets the value of the given attribute.

pub fn remove<A: StylingAttribute<Self>>(self, attr: A) -> Self

Clears the given attribute.

Source

impl Style

pub fn bold(self) -> Style

Sets the bold effect.

pub fn faint(self) -> Style

Sets the faint effect.

pub fn italic(self) -> Style

Sets the italic effect.

pub fn underline(self) -> Style

pub fn solid_underline(self) -> Style

Sets the solid underline effect.

pub fn curly_underline(self) -> Style

Sets the curly underline effect.

pub fn dotted_underline(self) -> Style

Sets the dotted underline effect.

pub fn dashed_underline(self) -> Style

Sets the dashed underline effect.

Sets the blink effect.

pub fn reverse(self) -> Style

Sets the reverse effect.

pub fn conceal(self) -> Style

Sets the conceal effect.

pub fn strikethrough(self) -> Style

Sets the strikethrough effect.

pub fn double_underline(self) -> Style

Sets the double underline effect.

pub fn overline(self) -> Style

Sets the overline effect.

pub fn effect(self, effect: impl Into<Effect>) -> Style

Sets the given effect.

pub fn underline_effect(self, underline_effect: UnderlineEffect) -> Style

Sets the underline effect.

pub fn fg(self, color: impl Into<Color>) -> Style

Sets the foreground color.

pub fn bg(self, color: impl Into<Color>) -> Style

Sets the background color.

pub fn underline_color(self, color: impl Into<Color>) -> Style

Sets the underline color.

pub fn color(self, targeted_color: impl Into<TargetedColor>) -> Style

Sets the given color in a target.

pub fn add(self, element: impl StylingElement<Style>) -> Style

Adds the given element to the style.

pub fn applied_to<C: Display>(self, content: C) -> Styled<C>

Applies the styling to the given content, returning a Styled<C> instance.

Source

impl Style

pub fn to_style(self) -> Style

Convert this type into a Style.