pub trait StylingAttribute<S> {
type Value: Default;
// Required methods
fn set_in(self, composed_styling: S, value: Self::Value) -> S;
fn get_from(self, composed_styling: &S) -> Self::Value;
}Expand description
A trait to represent an attribute that can be set in or retrieved from any composed styling value.